@@ -13,7 +13,7 @@ class Number(DataNode[NumberTypes]):
 
     Attributes:
         data (NumberTypes): The int or float object.
-        name (str): The name of the element.
+        name (Hashable): The name of the element.
     """
 
     @classmethod
@@ -38,7 +38,7 @@ class String(DataNode[str]):
 
     Attributes:
         data (str): The string object.
-        name (str): The name of the element.
+        name (Hashable): The name of the element.
     """
 
     @classmethod
@@ -63,7 +63,7 @@ class Callable(DataNode[tp.Callable]):
 
     Attributes:
         data (Callable): The callable object.
-        name (str): The name of the element.
+        name (Hashable): The name of the element.
     """
 
     @classmethod
@@ -81,3 +81,25 @@ class Callable(DataNode[tp.Callable]):
 
         """
         return cls._validate_dtype(data, (tp.Callable,))
+
+
+@dataclass
+class Any(DataNode[tp.Any]):
+    """A class representing a any element.
+
+    Attributes:
+        data (Any): The any object.
+        name (Hashable): The name of the element.
+    """
+
+    @classmethod
+    def validate_data(cls, data: tp.Any) -> tp.Any:
+        """Validate the data to be any.
+
+        Args:
+            data (Any): The data to be validated.
+
+        Returns:
+            Any: The validated data.
+        """
+        return data
