@@ -89,7 +89,6 @@ class Solver(FunctionNode[Parameter, Record]):
 
         Args:
             inputs (list[Parameter]): The list of input `Parameter` for the solver function.
-            is_parsed_sampleset (bool, optional): Whether the sample set is parsed. Defaults to True.
 
         Raises:
             SolverFailedError: If an error occurs inside the solver function.
@@ -100,9 +99,13 @@ class Solver(FunctionNode[Parameter, Record]):
         from jijbench.solver.jijzept import SampleSet
 
         parameters = inspect.signature(self.function).parameters
-        solver_args = {
-            node.name: node.data for node in inputs if node.name in parameters
-        }
+        has_kwargs = any([p.kind == 4 for p in parameters.values()])
+        if has_kwargs:
+            solver_args = {node.name: node.data for node in inputs}
+        else:
+            solver_args = {
+                node.name: node.data for node in inputs if node.name in parameters
+            }
         try:
             rets = self.function(**solver_args)
             if not isinstance(rets, tuple):
