@@ -85,7 +85,7 @@ class UserDefinedModel(Parameter[ModelType]):
         ph_labels = [
             v.label
             for v in extract_vars_from_problem(problem)
-            if isinstance(v, jm.Placeholder)
+            if isinstance(v, jm.Placeholder) and not v.children()
         ]
 
         is_in_labels = list(map(lambda x: x in keys, ph_labels))
